{% load sitetree %}

<ul>
    {% for item in sitetree_items %}
        <li>
            <a href="{% sitetree_url for item %}" {% if item.hint %}title="{{ item.hint }}"{% endif %} {% if item.is_current or item.in_current_branch %}class="{{ item.is_current|yesno:'current_item ,' }}{{ item.in_current_branch|yesno:'current_branch,' }}"{% endif %}>
                {{ item.title_resolved }}  --  display_title: {{ item.display_title }}
            </a>
            {% if item.has_children %}
                {% sitetree_children of item for menu template "dynamic_sites/fractures/listmenu_translation.html" %}
            {% endif %}
        </li>
    {% endfor %}
</ul>