<!DOCTYPE html>
<html lang="en">
    {% load static sitetree i18n %}
    <head>
        <meta charset="UTF-8">
        <title>{% block title %}Default Title{% endblock title %}</title>

        <meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
        <meta name="description" content="" />
        <meta name="keywords" content="" />

        <link rel="stylesheet" href="{% static 'css/main.css' %}">

        <style>
            body:before {
                background-image: url('{{ bg_pic.url }}')
            }
        </style>
    </head>
    <body>
        <section class="wrapper">
            <div class="inner">
                <header class="special">
                    <h3>{{ object.display_title }}</h3>
                </header>
                <div>
                    <h4>Sitetree Menu</h4>
                    {% if object.parent %}
                    {% if not object.parent.parent %}
                        {% sitetree_menu from 'root' include 'trunk' template 'dynamic_sites/fractures/listmenu_translation.html' %}
                    {% else %}
                        {% sitetree_menu from 'root' include 'this-parent-siblings' template 'dynamic_sites/fractures/listmenu_translation.html' %}
                    {% endif %}
                    {% endif %}
                    {% sitetree_menu from 'root' include 'this-children' template 'dynamic_sites/fractures/listmenu_translation.html' %}
                    {% if not object.parent %}
                        {% sitetree_menu from 'root' include 'trunk' template 'dynamic_sites/fractures/listmenu_translation.html' %}
                    {% else %}
                        {% sitetree_menu from 'root' include 'this-siblings' template 'dynamic_sites/fractures/listmenu_translation.html' %}
                    {% endif %}
                </div>
                <div>
                    {% for obj in object_list %}
                        {% include obj.template.path with object=obj %}
                    {% endfor %}
                </div>
            </div>
        </section>
    </body>
</html>